@@ -20,6 +20,7 @@ use UNIVERSAL::require;
 use XML::TreePP;
 
 use FusionInventory::Agent::Tools;
+use FusionInventory::Agent::Tools::SNMP;
 use FusionInventory::Agent::Tools::Network;
 use FusionInventory::Agent::Task::NetDiscovery::Dictionary;
 use FusionInventory::Agent::XML::Query;
@@ -31,156 +32,6 @@ if ($threads::shared::VERSION < 1.21) {
 
 our $VERSION = '2.2.0';
 
-my %hardware_keywords = (
-    '3com'           => { vendor => '3Com',            type => 'NETWORKING' },
-    'alcatel-lucent' => { vendor => 'Alcatel-Lucent',  type => 'NETWORKING' },
-    'allied'         => { vendor => 'Allied',          type => 'NETWORKING' },
-    'alteon'         => { vendor => 'Alteon',          type => 'NETWORKING' },
-    'apc'            => { vendor => 'APC',             type => 'NETWORKING' },
-    'apple'          => { vendor => 'Apple',           type => 'NETWORKING' },
-    'avaya'          => { vendor => 'Avaya',           type => 'NETWORKING' },
-    'axis'           => { vendor => 'Axis',            type => 'NETWORKING' },
-    'baystack'       => { vendor => 'Nortel',          type => 'NETWORKING' },
-    'broadband'      => { vendor => 'Broadband',       type => 'NETWORKING' },
-    'brocade'        => { vendor => 'Brocade',         type => 'NETWORKING' },
-    'brother'        => { vendor => 'Brother',         type => 'NETWORKING' },
-    'canon'          => { vendor => 'Canon',           type => 'PRINTER'    },
-    'cisco'          => { vendor => 'Cisco',           type => 'NETWORKING' },
-    'dell'           => { vendor => 'Dell',            type => 'NETWORKING' },
-    'designjet'      => { vendor => 'Hewlett Packard', type => 'PRINTER'    },
-    'deskjet'        => { vendor => 'Hewlett Packard', type => 'PRINTER'    },
-    'dlink'          => { vendor => 'Dlink',           type => 'NETWORKING' },
-    'eaton'          => { vendor => 'Eaton',           type => 'NETWORKING' },
-    'emc'            => { vendor => 'EMC',                                  },
-    'enterasys'      => { vendor => 'Enterasys',       type => 'NETWORKING' },
-    'epson'          => { vendor => 'Epson',           type => 'PRINTER'    },
-    'extreme'        => { vendor => 'Extrem Networks', type => 'NETWORKING' },
-    'extremexos'     => { vendor => 'Extrem Networks', type => 'NETWORKING' },
-    'foundry'        => { vendor => 'Foundry',         type => 'NETWORKING' },
-    'fuji'           => { vendor => 'Fuji',            type => 'NETWORKING' },
-    'h3c'            => { vendor => 'H3C',             type => 'NETWORKING' },
-    'hp'             => { vendor => 'Hewlett Packard',                      },
-    'ibm'            => { vendor => 'IBM',             type => 'NETWORKING' },
-    'juniper'        => { vendor => 'Juniper',         type => 'NETWORKING' },
-    'konica'         => { vendor => 'Konica',          type => 'PRINTER'    },
-    'kyocera'        => { vendor => 'Kyocera',         type => 'PRINTER'    },
-    'lexmark'        => { vendor => 'Lexmark',         type => 'PRINTER'    },
-    'netapp'         => { vendor => 'NetApp',                               },
-    'netgear'        => { vendor => 'NetGear',         type => 'NETWORKING' },
-    'nortel'         => { vendor => 'Nortel',          type => 'NETWORKING' },
-    'nrg'            => { vendor => 'NRG',             type => 'NETWORKING' },
-    'officejet'      => { vendor => 'Hewlett Packard', type => 'PRINTER'    },
-    'oki'            => { vendor => 'OKI',             type => 'PRINTER'    },
-    'powerconnect'   => { vendor => 'PowerConnect',    type => 'NETWORKING' },
-    'procurve'       => { vendor => 'Hewlett Packard', type => 'NETWORKING' },
-    'ricoh'          => { vendor => 'Ricoh',           type => 'PRINTER'    },
-    'sagem'          => { vendor => 'Sagem',           type => 'NETWORKING' },
-    'samsung'        => { vendor => 'Samsung',         type => 'NETWORKING' },
-    'sharp'          => { vendor => 'Sharp',           type => 'NETWORKING' },
-    'toshiba'        => { vendor => 'Toshiba',         type => 'NETWORKING' },
-    'wyse'           => { vendor => 'Wyse',            type => 'NETWORKING' },
-    'xerox'          => { vendor => 'Xerox',           type => 'PRINTER'    },
-    'xirrus'         => { vendor => 'Xirrus',          type => 'NETWORKING' },
-    'zebranet'       => { vendor => 'Zebranet',        type => 'NETWORKING' },
-    'ztc'            => { vendor => 'ZTC',             type => 'NETWORKING' },
-    'zywall'         => { vendor => 'ZyWall',          type => 'NETWORKING' }
-);
-
-my @hardware_rules = (
-    {
-        match       => qr/^\S+ Service Release/,
-        description => { function => 'FusionInventory::Agent::Manufacturer::Alcatel::getDescription' },
-        vendor      => { value    => 'Alcatel' }
-    },
-    {
-        match       => qr/AXIS OfficeBasic Network Print Server/,
-        description => { function => 'FusionInventory::Agent::Manufacturer::Axis::getDescription' },
-        vendor      => { value    => 'Axis' },
-        type        => { value    => 'PRINTER' }
-    },
-    {
-        match       => qr/Linux/,
-        description => { oid   => '.1.3.6.1.2.1.1.5.0' },
-        vendor      => { value => 'Ddwrt' }
-    },
-    {
-        match       => qr/^Ethernet Switch$/,
-        description => { oid   => '.1.3.6.1.4.1.674.10895.3000.1.2.100.1.0' },
-        vendor      => { value => 'Dell' },
-        type        => { value => 'NETWORKING' }
-    },
-    {
-        match       => qr/EPSON Built-in/,
-        description => { oid   => '.1.3.6.1.4.1.1248.1.1.3.1.3.8.0' },
-        vendor      => { value => 'Epson' },
-    },
-    {
-        match       => qr/EPSON Internal 10Base-T/,
-        description => { oid   => '.1.3.6.1.2.1.25.3.2.1.3.1' },
-        vendor      => { value => 'Epson' },
-    },
-    {
-        match       => qr/HP ETHERNET MULTI-ENVIRONMENT/,
-        description => { function => 'FusionInventory::Agent::Manufacturer::HewlettPackard::getDescription' },
-        vendor      => { value    => 'Hewlett-Packard' }
-    },
-    {
-        match       => qr/A SNMP proxy agent, EEPROM/,
-        description => { function => 'FusionInventory::Agent::Manufacturer::HewlettPackard::getDescription' },
-        vendor      => { value    => 'Hewlett-Packard' }
-    },
-    {
-        match       => qr/,HP,JETDIRECT,J/,
-        description => { oid   => '.1.3.6.1.4.1.1229.2.2.2.1.15.1' },
-        vendor      => { value => 'Kyocera' },
-        type        => { value => 'PRINTER' }
-    },
-    {
-        match       => qr/^KYOCERA (MITA Printing System|Print I\/F)$/,
-        description => { function => 'FusionInventory::Agent::Manufacturer::Kyocera::getDescription' },
-        vendor      => { value    => 'Kyocera' },
-        type        => { value    => 'PRINTER' }
-    },
-    {
-        match       => qr/^SB-110$/,
-        description => { function => 'FusionInventory::Agent::Manufacturer::Kyocera::getDescription' },
-        vendor      => { value    => 'Kyocera' },
-        type        => { value    => 'PRINTER' }
-    },
-    {
-        match       => qr/RICOH NETWORK PRINTER/,
-        description => { oid => '.1.3.6.1.4.1.11.2.3.9.1.1.7.0' },
-        vendor      => { value => 'Ricoh' },
-        type        => { value => 'PRINTER' }
-    },
-    {
-        match       => qr/SAMSUNG NETWORK PRINTER,ROM/,
-        description => { oid => '.1.3.6.1.4.1.236.11.5.1.1.1.1.0' },
-        vendor      => { value => 'Samsung' },
-        type        => { value => 'PRINTER' }
-    },
-    {
-        match       => qr/Samsung(.*);S\/N(.*)/,
-        description => { oid => '.1.3.6.1.4.1.236.11.5.1.1.1.1.0' }
-    },
-    {
-        match        => qr/Linux/,
-        description => { function => 'FusionInventory::Agent::Manufacturer::Wyse::getDescription' },
-        vendor      => { value    => 'Wyse' },
-    },
-    {
-        match       => qr/ZebraNet PrintServer/,
-        description => { function => 'FusionInventory::Agent::::Manufacturer::Zebranet::getDescription' },
-        vendor      => { value    => 'Zebranet' },
-        type        => { value    => 'PRINTER' }
-    },
-    {
-        match       => qr/ZebraNet Wired PS/,
-        description => { function => 'FusionInventory::Agent::Manufacturer::Zebranet::getDescription' },
-        vendor      => { value    => 'Zebranet' },
-    },
-);
-
 sub isEnabled {
     my ($self, $response) = @_;
 
@@ -624,43 +475,24 @@ sub _scanAddressBySNMP {
         # try to get a matching model from the dictionary
         my $model = $params{snmp_dictionary}->getModel($sysdescr);
 
+        # first, we initialize with some generic information
+        %device = getBasicInfoFromSysdescr($sysdescr, $snmp);
+
+        $device{MAC} = _getMacAddress($snmp);
+
+
+        # then we use the available information from the model
         if ($model) {
-            # use model as primary identification source
 
             $device{SERIAL}    = _getSerial($snmp, $model);
             $device{MAC}       = _getMacAddress($snmp, $model) ||
                                  _getMacAddress($snmp);
             $device{MODELSNMP}    = $model->{MODELSNMP};
-            $device{TYPE}         = $model->{TYPE};
-            $device{MANUFACTURER} = $model->{MANUFACTURER};
+            $device{TYPE}         = $model->{TYPE} if $model->{TYPE};
+            $device{MANUFACTURER} = $model->{MANUFACTURER} if $model->{MANUFACTURER};
             $device{FIRMWARE}     = $model->{FIRMWARE};
             $device{MODEL}        = $model->{MODEL};
 
-            foreach my $rule (@hardware_rules) {
-                next unless $sysdescr =~ $rule->{match};
-                $device{DESCRIPTION} = _apply_rule($rule->{description}, $snmp);
-                last;
-            }
-        } else {
-            # use rules as fallback
-
-            $device{MAC} = _getMacAddress($snmp);
-
-            my ($first_word) = $sysdescr =~ /^(\S+)/;
-            my $keyword = $hardware_keywords{lc($first_word)};
-
-            if ($keyword) {
-                $device{MANUFACTURER} = $keyword->{vendor};
-                $device{TYPE}         = $keyword->{type};
-            } else {
-                foreach my $rule (@hardware_rules) {
-                    next unless $sysdescr =~ $rule->{match};
-                    $device{MANUFACTURER} = _apply_rule($rule->{vendor}, $snmp);
-                    $device{TYPE}         = _apply_rule($rule->{type}, $snmp);
-                    $device{DESCRIPTION}  = _apply_rule($rule->{description}, $snmp);
-                    last;
-                }
-            }
         }
 
         $device{AUTHSNMP}     = $credential->{ID};
@@ -757,31 +589,6 @@ sub _parseNmap {
     return $result;
 }
 
-sub _apply_rule {
-    my ($rule, $snmp) = @_;
-
-    return unless $rule;
-
-    if ($rule->{value}) {
-        return $rule->{value};
-    }
-
-    if ($rule->{oid}) {
-        return $snmp->get($rule->{oid});
-    }
-
-    if ($rule->{function}) {
-        my ($module, $function) = $rule->{function} =~ /^(\S+)::(\S+)$/;
-        return runFunction(
-            module   => $module,
-            function => $function,
-            params   => $snmp,
-            load     => 1
-        );
-    }
-}
-
-
 1;
 
 __END__
